pub struct Fallback { /* private fields */ }Expand description
Control node that tries children in order until one succeeds.
Fallback ticks children in order on each tick:
- returns
TickStatus::Successas soon as a child succeeds - returns
TickStatus::Runningas soon as a child is still running - returns
TickStatus::Failureonly if every child fails on the same tick
This variant does not remember which child was previously running, so the next tick starts again from the first child.
Implementations