MemorySequence

Struct MemorySequence 

pub struct MemorySequence { /* private fields */ }
Memory-based Sequence variant.

Unlike Sequence, MemorySequence remembers the last running child and resumes from it on the next tick instead of restarting from the beginning.

Implementations

Source

impl MemorySequence

pub fn new(nodes: impl Into<NonEmptyNodes>) -> Self