pub struct ParallelParams {
pub success_count: u16,
pub failure_count: u16,
}Expand description
Threshold configuration for Parallel.
Fields
success_count: u16Number of children that must succeed for the node to succeed.
failure_count: u16Number of children that must fail for the node to fail.
Implementations
Sourceimpl ParallelParams
impl ParallelParams
Sourcepub fn builder() -> ParallelParamsBuilder
pub fn builder() -> ParallelParamsBuilder
Create an instance of ParallelParams using the builder syntax