pub struct Sequence { /* private fields */ }Expand description
Control node that requires all children to succeed in order.
Sequence ticks children from left to right on each tick:
- returns
TickStatus::Failureas soon as a child fails - returns
TickStatus::Runningas soon as a child is still running - returns
TickStatus::Successonly if every child succeeds on the same tick
This variant does not remember which child was previously running, so the next tick starts again from the first child.
Implementations